#
# spec file for package ima-evm-utils
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define sover 0
%define libname libimaevm%{sover}
Name:           ima-evm-utils
Version:        1.1
Release:        lp150.1.1
Summary:        IMA/EVM control utility
License:        LGPL-2.1+
Group:          System/Base
Url:            http://sourceforge.net/projects/linux-ima/
Source0:        http://downloads.sourceforge.net/project/linux-ima/ima-evm-utils/%{name}-%{version}.tar.gz
Patch2:         ima-evm-utils-fix-docbook-xsl-directory.patch
BuildRequires:  asciidoc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  keyutils-devel
BuildRequires:  libattr-devel
BuildRequires:  libtool
BuildRequires:  libxslt-tools
BuildRequires:  openssl-devel
BuildRequires:  pkgconfig

%description
This package provides the control utility for IMA/EVM (Integrity
Measurement Architecture/ Linux Extended Verification Module).

%package devel
Summary:        Development files for the IMA/EVM control utility library
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Requires:       openssl-devel

%description devel
This package contains the header files and the utilities for %{name}.

%package -n %{libname}
Summary:        IMA/EVM control utility libary
Group:          System/Libraries

%description -n %{libname}
This package provides the shared library for IMA/EVM (Integrity
Measurement Architecture/Extended Verification Module).

%package -n evmctl
Summary:        IMA/EVM signing utility
Group:          System/Kernel
Provides:       ima-evm-utils = %{version}
Obsoletes:      ima-evm-utils < %{version}

%description -n evmctl
The evmctl utility can be used for producing and verifying digital signatures,
which are used by Linux kernel integrity subsystem (IMA/EVM). It can be also
used to import keys into the kernel keyring.

%prep
%setup -q
%if 0%{?suse_version} >= 1315
%patch2 -p1
%endif

%build
autoreconf -fiv
%configure \
  --disable-static
make %{?_smp_mflags}

%install
%make_install
# Let do it by ourselves later...
rm -rf %{buildroot}%{_datadir}/doc
find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{libname} -p /sbin/ldconfig
%postun -n %{libname} -p /sbin/ldconfig

%files devel
%doc examples/*
%{_includedir}/*
%{_libdir}/libimaevm.so

%files -n %{libname}
%doc README COPYING NEWS AUTHORS
%{_libdir}/libimaevm.so.%{sover}*

%files -n evmctl
%{_bindir}/evmctl
%{_mandir}/man1/evmctl.1%{ext_man}

%changelog
* Fri Mar 16 2018 pvorel@suse.cz
- Update to version 1.1 (fate#323906)
  * Support the new openssl 1.1 api
  * Support for validating multiple pcrs
  * Verify the measurement list signature based on the list digest
  * Verify the "ima-sig" measurement list using multiple keys
  * Fixed parsing the measurement template data field length
  * Portable & immutable EVM signatures (new format)
  * Multiple fixes that have been lingering in the next branch. Some
    are for experimental features that are not yet supported in the
    kernel.
- Drop ima-evm-utils-openssl1.patch (not needed any more as IMA got
  backward compatible support for openssl 1.1).
* Tue Nov 21 2017 mpluskal@suse.com
- Small spec file cleanup with spec-cleaner
* Wed Nov  8 2017 meissner@suse.com
- ima-evm-utils-openssl1.patch: allow building against openssl 1.1 (bsc#1066947)
* Mon Oct 23 2017 matthias.gerstner@suse.com
- added openssl-devel dependency to ima-evm-utils-devel. otherwise the ima
  header can't be included if the openssl headers are missing
* Sat Oct 14 2017 jengelh@inai.de
- No need to remove .a files which don't exist.
- Drop extraneous ldconfig call on preun.
- Update RPM groups and descriptions.
* Fri Oct 13 2017 matthias.gerstner@suse.com
- ima-evm-utils-fix-docbook-xsl-directory.patch: adjusted to refer to the
  "current" version of stylesheet to make the build work again
- adjusted spec file to apply stylesheet patch to SLE12 as well
* Mon May  8 2017 meissner@suse.com
- Add ima-evm-utils to SLES. (FATE#321603)
* Tue Jan 19 2016 meissner@suse.com
- ima-evm-utils-fix-docbook-xsl-directory.patch:
  fixed the nwalsh docbook directory again
* Wed Dec  2 2015 p.drouand@gmail.com
- Update to version 1.0
  * Recursive hashing
  * Immutable EVM signatures (experimental)
  * Command 'ima_clear' to remove xattrs
  * Support for passing password to the library
  * Support for asking password safely from the user
* Wed Jan 21 2015 p.drouand@gmail.com
- Update to version 0.9
  * Updated README
  * man page generated and added to the package
  * Use additional SMACK xattrs for EVM signature generation
  * Signing functions moved to libimaevm for external use (RPM)
  * Fixed setting of correct hash header
- Add additional requirements; asciidoc, docbook-xsl-stylesheets,
  libattr-devel and libxslt-tools
- Remove COPYING from sources; upstream provides one now
- Remove automake.patch; "test" directory isn't provided by upstream
  anymore
- Remove ima-evm-utils-xattr.patch; libimaevm0 does link against
  libattr now
- Split package in three subpackage
  * libimaevm0: contains shared library
  * -devel: contains header and examples files
  * evmctl: the kernel signing tool
- Add ima-evm-utils-fix-docbook-xsl-directory.patch; fix path
  where Make is looking for docbook.xsl
* Sun Oct 12 2014 crrodriguez@opensuse.org
- ima-evm-utils-xattr.patch: libattr is never linked, things
  still work because glibc provides the same interface, switch
  the includes to the glibc headers and remove the build dependency.
* Tue Aug 13 2013 meissner@suse.com
- Initial packaging of IMA EVM tool.
- automake.patch: fix for newer automake
- supply COPYING for LGPL-2.1+, as package only has an empty one.
